# -*- coding: utf-8 -*-
#
# Copyright (C) 2021 Avencall
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>

from sqlalchemy.schema import Column, PrimaryKeyConstraint, UniqueConstraint
from sqlalchemy.types import Integer, String, Text
from sqlalchemy.dialects.postgresql import UUID
from sqlalchemy import text, ForeignKey

from xivo_dao.helpers.db_manager import Base


class MeetingRoom(Base):
    __tablename__ = 'meetingroom'
    __table_args__ = (
        PrimaryKeyConstraint('id'),
        UniqueConstraint('name'),
        UniqueConstraint('number'),
    )

    id = Column(Integer, nullable=False, autoincrement=True)
    uuid = Column(UUID(as_uuid=True), nullable=False, server_default=text('uuid_generate_v4()'))
    name = Column(String(128), nullable=False)
    display_name = Column(String(128), nullable=False)
    number = Column(String(40), nullable=True)
    user_pin = Column(String(12), nullable=True)
    type = Column(String(40), nullable=False, server_default='static')
    user_id = Column(Integer, ForeignKey('userfeatures.id', ondelete="CASCADE"), nullable=True)
